@@ -47,6 +47,7 @@
 int nodaemon = false;
 unsigned int screen_width;
 unsigned int screen_height;
+int do_mouse_reporting  = true;
 enum mouse_reporting_mode mouse_reporting = MOUSE_REPORTING_OFF;
 
 static struct tools_options options;
@@ -248,6 +249,10 @@ usage(void)
          "--disable-middlebutton.... enable/disable middle button emulation\n"
          "--enable-dwt\n"
          "--disable-dwt.... enable/disable disable-while-typing\n"
+#ifdef HAVE_LIBINPUT_1_21
+         "--enable-dwtp\n"
+         "--disable-dwtp.... enable/disable disable-while-trackpointing\n"
+#endif
 #ifdef HAVE_LIBINPUT_1_15
          "--enable-scroll-button-lock\n"
          "--disable-scroll-button-lock.... enable/disable the scroll button lock\n"
@@ -263,14 +268,15 @@ usage(void)
          "is not explicitly specified it is left at each device's default.\n"
          "\n"
          "Other options:\n"
-         "--word-chars=<string>.... List of characters that make up words.\n"
+         "--word-chars=<string>.... list of characters that make up words.\n"
          "                          Ranges (a-z, A-Z, 0-9 etc.) are allowed.\n"
-         "--grab .......... Exclusively grab all opened devices.\n"
-         "--map button=action set button to action.\n"
-         "--no-daemon...... Do not detach and run in the background.\n"
-         "--verbose ....... Print debugging output.\n"
-         "--version ....... Print version information.\n"
-         "--help .......... Print this help.\n",
+         "--grab .......... exclusively grab all opened devices.\n"
+         "--map button=action .... set button to action.\n"
+         "--no-daemon ..... do not detach and run in the background.\n"
+         "--disable-mouse-reporting .... disable mouse reporting.\n"
+         "--verbose ....... print debugging output.\n"
+         "--version ....... print version information.\n"
+         "--help .......... print this help.\n",
          program_invocation_short_name);
   return 1;
 }
@@ -318,7 +324,8 @@ parse_args(int argc, char **argv)
       OPT_HELP,
       OPT_VERBOSE,
       OPT_VERSION,
-      OPT_WORD_CHARS
+      OPT_WORD_CHARS,
+      OPT_DISABLE_MOUSE_REPORTING
     };
     static struct option opts[] = {
       CONFIGURATION_OPTIONS,
@@ -331,6 +338,7 @@ parse_args(int argc, char **argv)
       { "verbose",                   no_argument,       0, OPT_VERBOSE },
       { "version",                   no_argument,       0, OPT_VERSION },
       { "word-chars",                required_argument, 0, OPT_WORD_CHARS },
+      { "disable-mouse-reporting",   no_argument,       0, OPT_DISABLE_MOUSE_REPORTING },
       { 0, 0, 0, 0}
     };
 
@@ -397,6 +405,9 @@ parse_args(int argc, char **argv)
         action_map[button - 0x100] = action - 0x100;
     }
       break;
+    case OPT_DISABLE_MOUSE_REPORTING:
+      do_mouse_reporting = false;
+      break;
     default:
       if (tools_parse_option(c, optarg, &options) != 0) {
         usage();
