@@ -1,5 +1,5 @@
 /* Adapted from test/shared.h from the libinput distribution */
-/* tools/shared.h 1.15.5:
+/* tools/shared.h 1.21.0:
  *
  * Copyright © 2014 Red Hat, Inc.
  * Modifications: Copyright © 2019 Bill Allombert <ballombe@debian.org>
@@ -47,6 +47,8 @@ enum configuration_options {
 	OPT_MIDDLEBUTTON_DISABLE,
 	OPT_DWT_ENABLE,
 	OPT_DWT_DISABLE,
+	OPT_DWTP_ENABLE,
+	OPT_DWTP_DISABLE,
 	OPT_CLICK_METHOD,
 	OPT_SCROLL_METHOD,
 	OPT_SCROLL_BUTTON,
@@ -74,6 +76,8 @@ enum configuration_options {
 	{ "disable-middlebutton",      no_argument,       0, OPT_MIDDLEBUTTON_DISABLE }, \
 	{ "enable-dwt",                no_argument,       0, OPT_DWT_ENABLE }, \
 	{ "disable-dwt",               no_argument,       0, OPT_DWT_DISABLE }, \
+	{ "enable-dwtp",               no_argument,       0, OPT_DWTP_ENABLE }, \
+	{ "disable-dwtp",              no_argument,       0, OPT_DWTP_DISABLE }, \
 	{ "enable-scroll-button-lock", no_argument,       0, OPT_SCROLL_BUTTON_LOCK_ENABLE }, \
 	{ "disable-scroll-button-lock",no_argument,       0, OPT_SCROLL_BUTTON_LOCK_DISABLE }, \
 	{ "set-click-method",          required_argument, 0, OPT_CLICK_METHOD }, \
@@ -106,6 +110,7 @@ struct tools_options {
 	int scroll_button_lock;
 	double speed;
 	int dwt;
+	int dwtp;
 	enum libinput_config_accel_profile profile;
 	char disable_pattern[64];
 };
